cmd

package
v0.44.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 28, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version = "dev"

Version is set at build time via ldflags:

go build -ldflags "-X github.com/dotcommander/cclint/cmd.Version=1.0.0"

Functions

func Execute

func Execute()

Types

type ComponentSummary

type ComponentSummary struct {
	TotalComponents int
	AgentCount      int
	CommandCount    int
	SkillCount      int
	TierCounts      map[string]int
	TopIssues       map[string]int
	LowestScoring   []ScoredComponent
	AllResults      []lint.LintResult
}

ComponentSummary holds aggregated data for summary report

type LinterFunc

type LinterFunc = lint.LinterFunc

LinterFunc is the function signature for component linters. It takes root path, quiet mode, verbose mode, noCycleCheck and returns a summary.

type ScoredComponent

type ScoredComponent struct {
	File  string
	Type  string
	Score int
	Tier  string
}

ScoredComponent represents a component with its score for sorting

Jump to