types

package
v0.45.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package types provides shared types used across the cclint codebase. This package is at the bottom of the dependency graph and should not import any other internal packages to avoid circular dependencies.

Index

Constants

const (
	SourceAnthropicDocs = "anthropic-docs"     // Official Anthropic documentation
	SourceCClintObserve = "cclint-observation" // Our best practice observations
	SourceAgentSkillsIO = "agentskills-io"     // agentskills.io specification
)

Rule source constants.

const (
	SeverityError      = "error"
	SeverityWarning    = "warning"
	SeveritySuggestion = "suggestion"
	SeverityInfo       = "info"
)

Severity level constants.

const (
	TypeAgent   = "agent"
	TypeCommand = "command"
	TypeSkill   = "skill"
	TypeRule    = "rule"
)

Component type constants.

const (
	TypeHTTP = "http"
)

Hook type constants.

Variables

This section is empty.

Functions

This section is empty.

Types

type ValidationError

type ValidationError struct {
	File     string
	Message  string
	Severity string // error, warning, suggestion, info
	Source   string // anthropic-docs, cclint-observation, agentskills-io
	Line     int
	Column   int
}

ValidationError represents a validation error or warning.

Jump to